@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.11 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.12 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,25 +35,11 @@
 /**
  * WEB̥顼ɽ饹
  *
- * 顼åɽѥ
- * ư顼1
- *   ̥顼ɽ
- *   end( '顼å' )
- * 
- * ư顼2
- *   ̥顼̤˥顼åߤơ쵤ɽ
- *   
- *   end(顼å֥)
- * 
- * ư顼
- *   顼ϥɥ
- *   ̥顼ɽ塢λ
- * 
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.11 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.12 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -62,7 +48,6 @@ class SyL_ErrorWeb extends SyL_Error
      * 顼ϥɥ顼μ
      * 
      * @access public
-     * @param object ǡ֥
      */
     function errorHandler()
     {
@@ -70,10 +55,10 @@ class SyL_ErrorWeb extends SyL_Error
         // ɬ
         ob_clean();
 
+        // 顼פμ
+        $error_type = $this->getErrorType();
         // 顼å
         $error_message = implode('<br>', $this->getErrorMessages());
-        // 顼פμ
-        $error_type  = $this->getErrorType();
         // 顼ȥ졼μ
         $error_trace = SYL_ERROR_TRACE ? $this->getTraceHtml() : '';
 
@@ -127,61 +112,28 @@ class SyL_ErrorWeb extends SyL_Error
     function displayErrorTemplate($error_string, $error_trace, $view_type)
     {
         // ǡ饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
-        $dm =& new SyL_DataManager($this->controller);
-        $dm->setViewParameter('viewtype', $view_type[1]);
+        $this->dm->setViewParameter('viewtype', $view_type[1]);
         if ($view_type[0] == 'layout') {
-            $dm->setViewParameter('viewlayout', 'true');
+            $this->dm->setViewParameter('viewlayout', 'true');
         } else {
-            $dm->setViewParameter('viewlayout', 'false');
+            $this->dm->setViewParameter('viewlayout', 'false');
             if ($view_type[1] == 'customize') {
-                $dm->setViewParameter('customizedviewclass', $view_type[2]);
-                $dm->setViewParameter('customizedviewfile',  $view_type[3]);
+                $this->dm->setViewParameter('customizedviewclass', $view_type[2]);
+                $this->dm->setViewParameter('customizedviewfile',  $view_type[3]);
             }
         }
-        $dm->setTemplateFile(SYL_ERROR_FORWARD_FILE);
-        $dm->setParameter('error_message', $error_string);
-        $dm->setParameter('error_trace',   $error_trace);
+        $this->dm->setTemplateFile(SYL_ERROR_FORWARD_FILE);
+        $this->dm->setParameter('error_message', $error_string);
+        $this->dm->setParameter('error_trace',   $error_trace);
 
         // ӥ塼饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_Layout.php';
-        $view =& SyL_Layout::getObject($dm);
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
+        $view =& SyL_View::getObject($this->dm);
         $view->render();
 
         // ̱饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_Response.php';
-        $res =& SyL_Response::getInstance();
-        $res->display($view);
-    }
-
-    /**
-     * 쥤ȥ顼
-     *
-     * @access private
-     * @param string 顼å
-     * @param string 顼ȥ졼
-     * @param string ӥ塼
-     */
-    function displayErrorView($error_string, $error_trace, $view_type)
-    {
-        // ǡ饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
-        $dm =& new SyL_DataManager($this->controller);
-        $dm->setViewParameter('defaultView', $view_type);
-        $dm->setViewParameter('defaultView', $view_type);
-        $dm->setTemplateFile(SYL_ERROR_FORWARD_FILE);
-        $dm->setParameter('error_message', $error_string);
-        $dm->setParameter('error_trace',   $error_trace);
-
-        // ӥ塼饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_Layout.php';
-        $view =& SyL_Layout::getObject($dm);
-        $view->render();
-
-        // ̱饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_Response.php';
-        $res =& SyL_Response::getInstance();
-        $res->display($view);
+        $response =& SyL_Response::getInstance();
+        $response->display($view);
     }
 
     /**
