@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -65,9 +65,9 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -137,17 +137,6 @@ class SyL_RouterParameter extends SyL_Router
             }
         }
 
-        // URL
-        $syl_self = $_SERVER['PHP_SELF'];
-        if ($pathinfo == '') {
-            $syl_self = $syl_self . '/';
-        } else if (substr($pathinfo, -1) == '/') {
-            $syl_self = $syl_self;
-        } else {
-            $syl_self = dirname($syl_self) . '/';
-        }
-        $this->setSyLSelf($syl_self);
-
 /*
 echo "pathinfo: " . $pathinfo . "<br>";
 echo "action_name: " . $this->action_name . "<br>";
