@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -60,9 +60,9 @@
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.8 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.9 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -131,17 +131,6 @@ class SyL_RouterPathinfo extends SyL_Router
             $this->class_name = $classname;
         }
 
-        // URL
-        $syl_self = $_SERVER['PHP_SELF'];
-        if ($pathinfo == '') {
-            $syl_self = $syl_self . '/';
-        } else if (substr($pathinfo, -1) == '/') {
-            $syl_self = $syl_self;
-        } else {
-            $syl_self = dirname($syl_self) . '/';
-        }
-        $this->setSyLSelf($syl_self);
-
 /*
 echo "script_name: " . $script_name . "<br>";
 echo "pathinfo: " . $pathinfo . "<br>";
