@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.6 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.7 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.6 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ComponentMethod.php,v 1.7 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ComponentMethod
@@ -83,7 +83,7 @@ class SyL_ComponentMethod
      * @param string ե륿̾
      * @return mixed ե륿
      */
-    function triggerFilter($name)
+    function triggerFilter($name, $args)
     {
         $name = "__filter_{$name}";
         $component =& $this->getComponent($name);
@@ -99,7 +99,7 @@ class SyL_ComponentMethod
      * @param string ץꥱ󥳥ݡͥ̾
      * @return mixed ץꥱ󥳥ݡͥȤ
      */
-    function triggerApp($name)
+    function triggerApp($name, $args)
     {
         // Ͽå
         $match = false;
@@ -115,8 +115,6 @@ class SyL_ComponentMethod
         }
 
         $component =& $this->getComponent($name);
-        $args = func_get_args();
-        array_shift($args);
         return call_user_func_array(array(&$component, $this->direct_method), $args);
     }
 
