@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.5 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.6 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,9 +42,9 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_ComponentMethod.php';
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.5 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.6 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataManager
@@ -267,7 +267,9 @@ class SyL_DataManager
      */
     function triggerFilter($name)
     {
-        return $this->cm->triggerFilter($name);
+        $args = func_get_args();
+        array_shift($args);
+        return $this->cm->triggerFilter($name, $args);
     }
 
     /**
@@ -279,7 +281,9 @@ class SyL_DataManager
      */
     function triggerApp($name)
     {
-        return $this->cm->triggerApp($name);
+        $args = func_get_args();
+        array_shift($args);
+        return $this->cm->triggerApp($name, $args);
     }
 
     /**
