@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.11 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.12 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.11 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.12 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -58,13 +58,6 @@ class SyL_Error
      * @var string
      */
     var $eof = "\r\n";
-    /**
-     * ȥ饪֥
-     * 
-     * @access protected
-     * @var object
-     */
-    var $controller = null;
     /**
      * ǡ֥
      * 
@@ -72,6 +65,13 @@ class SyL_Error
      * @var object
      */
     var $dm = null;
+    /**
+     * ȥ
+     * 
+     * @access protected
+     * @var object
+     */
+    var $controller = null;
 
     /**
      * 󥹥ȥ饯
@@ -93,9 +93,9 @@ class SyL_Error
      *   $SyL_Error =& SyL_Error::getInstance();
      *
      * @access public
-     * @param object ȥ
+     * @param object ȥ or ǡ֥
      */
-    function &getInstance(&$controller)
+    function &getInstance(&$dm)
     {
         static $singleton;
         if (!is_object($singleton)) {
@@ -103,7 +103,11 @@ class SyL_Error
             include_once SYL_INCLUDE_DIR . "/framework/Error/{$class_name}.php";
             // ҥ饹Υ󥹥
             $singleton = new $class_name();
-            $singleton->setController($controller);
+            if (strtolower(get_class($dm)) == 'syl_datamanager') {
+                $singleton->setDataManager($dm);
+            } else {
+                $singleton->setController($dm);
+            }
         }
         return $singleton;
     }
@@ -119,6 +123,18 @@ class SyL_Error
         $this->controller =& $controller;
     }
 
+    /**
+     * ǡ֥Ȥ򥻥å
+     *
+     * @access public
+     * @param object ǡ֥
+     */
+    function setDataManager(&$dm)
+    {
+        $this->dm =& $dm;
+        $this->setController($this->dm->controller);
+    }
+
     /**
      * 顼ϥɥ
      * 
