@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameter.php,v 1.2 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameter.php,v 1.3 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  * 
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestParameter.php,v 1.2 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestParameter.php,v 1.3 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestParameter
@@ -170,27 +170,28 @@ class SyL_RequestParameter
     function applyParameters($func)
     {
         $func_parameters = func_get_args();
-        $this->applyParametersRecursive($this->parameters, $func_parameters);
+        $func = array_shift($func_parameters);
+        $this->applyParametersRecursive($func, $this->parameters, $func_parameters);
     }
 
     /**
      * Sp[^Ɏw֐Kp
      * 
      * @access private
-     * @param array p[^z
      * @param string ֐
+     * @param array p[^
+     * @param array ֐p[^
      */
-    function applyParametersRecursive(&$parameters, $args)
+    function applyParametersRecursive($func, &$parameters, $args)
     {
         if (is_array($parameters)) {
             foreach($parameters as $key => $value) {
-                $this->applyParametersRecursive($parameters[$key], $args);
+                $this->applyParametersRecursive($func, $parameters[$key], $args);
             }
         } else {
             // Ƃ肠A^̂ݓKp
             if (is_string($parameters)) {
-                $func_name = array_shift($args);
-                $parameters = call_user_func_array($func_name, array_merge((array)$parameters, $args));
+                $parameters = call_user_func_array($func, array_merge((array)$parameters, $args));
             }
         }
     }
