@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.7 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.8 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.7 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.8 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -172,17 +172,6 @@ class SyL_Router
         return $this->pathinfo;
     }
 
-    /**
-     * URL˥å
-     *
-     * @access public
-     * @param string URL
-     */
-    function setSyLSelf($syl_self)
-    {
-        //define('SYL_SELF', $syl_self);
-    }
-
     /**
      * ǥ쥯ȥȥСб
      *
