@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,32 +25,44 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ɽ饹
+ * եɤ߹९饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
+
+/**
+ * ̹ǥ饹
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
 {
     /**
-     * ɲåѥ᡼
+     * 쥤ե̾
      * 
-     * @access protected
-     * @var string
+     * @access private
+     * @param string
      */
-    var $parameter = array();
+    var $layout_file_name = 'layouts.xml';
+    /**
+     * ե
+     * 
+     * @access private
+     * @var array
+     */
+    var $config = array();
     /**
      * ɽƤΥǡ
      * 
@@ -70,6 +82,7 @@ class SyL_View
      * 󥹥ȥ饯
      *
      * @access public
+     * @param object ǡ֥
      */
     function SyL_View(&$dm)
     {
@@ -86,28 +99,68 @@ class SyL_View
      */
     function &getObject(&$dm)
     {
-        $class_name = '';
-        $class_file = '';
-        $type = $dm->getTemplateType();
-        if (strtolower($type) == 'customize') {
-            $class_name = $dm->getCustomizedViewClass();
-            $class_file = $dm->getCustomizedViewFile();
-            if (!is_file($class_file)) {
-                $class_file1 = SYL_WEBAPP_LIB_DIR . "/{$class_file}";
-                if (!is_file($class_file1)) {
-                    trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
-                }
-                $class_file = $class_file1;
+        $view = null;
+        $type = $dm->getViewParameter('viewtype');
+        if ($dm->getViewParameter('viewlayout') === 'true') {
+            // Layout 饹
+            switch ($type) {
+            case 'smarty' : $class_name = 'SyL_ViewLayoutSmarty';  break;
+            case 'default': $class_name = 'SyL_ViewLayoutDefault'; break;
+            default: trigger_error("[SyL error] Layout type not found ({$type})", E_USER_ERROR);
             }
-        } else {
-            $class_name = 'SyL_View' . ucfirst($type);
             $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+            include_once $class_file;
+            $view =& new $class_name($dm);
+            $view->parseConfig($dm->controller);
+        } else {
+            switch ($type) {
+            case 'customize':
+                $class_name = $dm->getViewParameter('customizedviewclass');
+                $class_file = $dm->getViewParameter('customizedviewfile');
+                if (!is_file($class_file)) {
+                    $class_file1 = SYL_WEBAPP_LIB_DIR . "/{$class_file}";
+                    if (!is_file($class_file1)) {
+                        trigger_error("[SyL error] Customised View file not found ({$class_file} or {$class_file1})", E_USER_ERROR);
+                    }
+                    $class_file = $class_file1;
+                }
+                break;
+            case 'smarty':
+                $class_name = 'SyL_ViewSmarty';
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+                break;
+            case 'json':
+                $class_name = 'SyL_ViewJson';
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+                break;
+            case 'default':
+                $class_name = 'SyL_ViewDefault';
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+                break;
+            default:
+                trigger_error("[SyL error] View type not found ({$type})", E_USER_ERROR);
+            }
+
+            include_once $class_file;
+            $view =& new $class_name($dm);
         }
-        include_once $class_file;
-        $view =& new $class_name($dm);
+
         return $view;
     }
 
+    /**
+     * XMLեβϽ
+     *
+     * @access public
+     */
+    function parseConfig(&$controller)
+    {
+        $config_file = SYL_APP_DIR . "/{$this->layout_file_name}";
+        $reader =& SyL_Config::getObject('layouts', $config_file, $controller);
+        $reader->parseXML();
+        $this->config += $reader->getConfig();
+    }
+
     /**
      * ƥץ졼ȥǥ쥯ȥ
      * 
@@ -127,19 +180,11 @@ class SyL_View
      */
     function getTemplateFile()
     {
-        return $this->dm->getTemplateFile();
-    }
-
-    /**
-     * ɲåѥ᡼򥻥å
-     * 
-     * @access public
-     * @param string ѥ᡼̾
-     * @param string ѥ᡼
-     */
-    function setParameter($name, $value)
-    {
-        $this->parameter[$name] = $value;
+        if ($this->dm->getViewParameter('viewlayout') === 'true') {
+            return $this->config['file'];
+        } else {
+            return $this->dm->getTemplateFile();
+        }
     }
 
     /**
@@ -150,42 +195,23 @@ class SyL_View
      */
     function &getActionValues()
     {
-        // 󥪥֥ȼ
-        $action =& $this->dm->getAction();
-        // 
         $values = array();
-        // ѥ᡼
-        if (is_object($action)) {
-            // 󥪥֥Ȥ¸ߤʥ¹ԸˤʤС
-            // ץѥƥ
-            foreach (get_object_vars($action) as $key => $value) {
-                if (substr($key, 0, 1) != '_') {
-                    if (is_object($value)) {
-                        $values[$key] =& $value;
-                    } else {
-                        $values[$key] = $value;
-                    }
-                }
-            }
-        } else {
-            // 󥪥֥Ȥ¸ߤʤʥ¹̵ˤʤС
-            // Υ饹ǥեȥץѥƥ
-            $action_file = $this->dm->getActionDir() . $this->dm->getActionFile();
-            if (is_file($action_file)) {
-                include_once($action_file);
-                $action_class = $this->dm->getClassName();
-                if (class_exists($action_class)) {
-                    foreach (get_class_vars($action_class) as $key => $value) {
-                        $values[$key] = $value;
-                    }
-                }
+
+        // 쥤
+        if (isset($this->config['templates'])) {
+            $values += $this->config['templates'];
+        }
+        if (isset($this->config['view'])) {
+            foreach (array_keys($this->config['view']) as $template) {
+                $values[$template] = $this->dm->getTemplateFile();
             }
         }
+        if (isset($this->config['parameters'])) {
+            $values += $this->config['parameters'];
+        }
 
-        // ɲåѥ᡼
-        foreach ($this->parameter as $key => $value) {
-            $values[$key] = $value;
-        }
+        // ͤʤ
+        $values += $this->dm->getParameters();
 
         return $values;
     }
@@ -214,6 +240,7 @@ class SyL_View
      * ɽƤ
      * 
      * @access public
+     * @return string HTML
      */
     function getRender()
     {
